@@ -1,22 +1,30 @@
 package XML::Generator::RSS10::dc;
+{
+  $XML::Generator::RSS10::dc::VERSION = '0.02';
+}
 
 use strict;
 
 use base 'XML::Generator::RSS10::Module';
 
-
 sub NamespaceURI { 'http://purl.org/dc/elements/1.1/' }
 
-
-
 1;
 
-__END__
+# ABSTRACT: Support for the Dublin Core (dc) RSS 1.0 module
+
+
+
+=pod
 
 =head1 NAME
 
 XML::Generator::RSS10::dc - Support for the Dublin Core (dc) RSS 1.0 module
 
+=head1 VERSION
+
+version 0.02
+
 =head1 SYNOPSIS
 
     use XML::Generator::RSS10;
@@ -47,4 +55,20 @@ This module provides support for the Dublin Core (dc) RSS 1.0 module.
 This module handles all of the Dublin Core elements, such as
 "creator", "publisher", "date", etc.
 
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
 =cut
+
+
+__END__
+
